WebViewState class
Properties
-
consoleLog
↔ String
-
Logs the console information
getter/setter pair
-
controller
↔ InAppWebViewController?
-
the controller for the second webview
getter/setter pair
-
controllerOne
↔ InAppWebViewController?
-
the controller for the first webview
getter/setter pair
-
currentUrl
↔ String
-
The Url currently on the webview
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasListeners
→ bool
-
Whether any listeners are currently registered.
no setterinherited
-
isLoading
↔ bool
-
Controls if the webview is still loading
getter/setter pair
-
isShowingFirst
↔ bool
-
controls if the first webview is being displayed
getter/setter pair
-
reportLink
↔ String
-
the report link contains the url for the confirmation of transaction
getter/setter pair
-
response
↔ dynamic
-
the response object
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setConsole(String value)
→ void
-
Sets the console logger
-
setController(InAppWebViewController control)
→ void
-
Sets the second webview controller
-
setControllerOne(InAppWebViewController control)
→ void
-
Sets the controller for the first webview
-
setProgress(bool status)
→ void
-
monitors the loading progress of the webviews
-
setReportLink(String link)
→ void
-
-
setResponse(dynamic value)
→ void
-
Sets the response object state
-
setUrl(String value)
→ void
-
sets the state of the current url
-
switchView(bool value)
→ void
-
switches from one of the webviews to another
-
toString()
→ String
-
A string representation of this object.
inherited